function [X, preptime, solvetime, A, b, C, val] =  kdc_sdpnal_1(G, k)

% Formulates and solves k-disjoint-clique in SDPNAL for given graph G and
% desired number of cliques k.

%% Initialize data.

tic
% Get number of nodes.
n = length(G);

% Have m1=n row sum constraints.
m1 = n;
% Have m2=1 trace constraints.
m2 = 1;
% Number of nonedges m3 is equal to number of zero entries in off-diagonal
% positions of G.
m3 = 0.5*(n*(n-1) - sum(sum(G)) + trace(G)); 
% Set number of constraints (n + 1 + #nonedges).
m = m1 + m2 + m3;

% Number of semidefinite decision variables is number of diagonal entries
% plus upper/lower triangular entries.
%s = n*(n+1)/2;

%% Block for  slack variables.

blk{2, 1} = 'l'; % block is nonnegative vector.
blk{2, 2} = m1; % have one entry for each row sum constraint.

% Set At{2}: top left block is m1 by m1 identity, bottom right block is m3
% by m3 - identity.
At{2,1} = [speye(m1,m1); zeros(m2 + m3, m1)]';

C{2,1} = spalloc(m1,1,0);

% Allocate temp var for constraints.
Atemp = cell(1,m);

%% Block for semidefinite variable.
% Semidefinite block  d
blk{1,1} = 's';
blk{1,2} = n;
% Coefficient matrix for objective function is -ee'.
C{1,1} = -ones(n);
   

% Right-hand side of constraints. % Sparsify!!
e = ones(m1,1);
b = sparse(1:m1+1, [e;1],  [e;k], m,1);


%% Define rows of At{1} corresponding to row sums.

'row sums'
for i = 1:m1    
     % Set all entries of the i-th row of the i-th constraint matrix equal
     % to 1.
     temp = sparse(i*e, 1:m1, 0.5*e, m1, m1);     
     Atemp{i} = temp + temp'; %- sparse(i, i, 0.5, m1, m1);
end

%% Define rows of At corresponding to trace contraints.

Atemp{m1 + 1} = speye(n); % Matrix for trace is identity.

 %% Define entries of At{1} corresponding to nonnedge constraints.
 
 count = m1 + m2 + 1;
 
 % For each off-diagonal entry check if (i,j) in E.
 for i=1:n
     for j = (i+1):n
         if G(i,j) == 0
             Atemp{count} = spconvert([i,j,0.5; j,i,0.5; n,n, 0]);             
             count = count + 1;
         end
     end
 end
 
%% Convert Atemp to At.

% SDP block.
At{1,1} =svec(blk(1,:), Atemp)';
At{1,1} = At{1,1}{1}; size(At{1})

preptime = toc;

%% Call SDPNAL to solve.
tic
[val, X] = sdpnal(blk, At, C, b);
X = X{1};
solvetime=toc;

%% Output A, b
A = At{1,1}; A = A(:, 1:(n+1));
b = b(1: m1+m2);